
#include <adc.h>

#include "sensors.h"

#define CH_DC  ADC_CH0  

#define STATE_DC_NEW    1        
#define STATE_DC_BUSY   2
#define STATE_DC_READ   3



#pragma udata

unsigned int VALUE_DC=0u;

static unsigned char state = STATE_DC_NEW; // private variable
    
#pragma code

void sensors_init(void)
  {
    // Initialize voltage sensors
    OpenADC( 
        ADC_FOSC_32 // clock
        & ADC_RIGHT_JUST //Results in least significant bits
        & ADC_16_TAD // collection time interval
        ,
        CH_DC 
        & ADC_INT_OFF // not interrupts (use polling)
        & ADC_VREFPLUS_VDD // use +5 for reference voltage
        & ADC_VREFMINUS_VSS // use 0 for reference
        ,
        2 // bits 0 through "n" of the ADCON1 register
      );
      
  }

  
void sensors_update(void)
  {
    switch (state)
      {
        /*** SENSOR 1 ***/
        
        case STATE_DC_NEW:
            SetChanADC( CH_DC );
            ConvertADC(); 
            state = STATE_DC_BUSY;            
          break;
          
        case STATE_DC_BUSY:
            if (! BusyADC())
              state = STATE_DC_READ; 
          break;
          
        case STATE_DC_READ:
            VALUE_DC = ReadADC();
            state = STATE_DC_NEW; 
          break; 
        
      }
  }
  

